@@ -243,39 +243,13 @@ def upload_analysis(args: argparse.Namespace) -> Tuple[int, str]:
         response_str = response['Payload'].read().decode('utf-8')
         response_payload = json.loads(response_str)
 
-        if response_payload.get(
-                'errorMessage') or response_payload.get('statusCode') != 200:
-            # try deprecated version, using analysis-api gateway
-            deprecated_payload = {
-                'resource':
-                    '/upload',
-                'HTTPMethod':
-                    'POST',
-                'Body':
-                    json.dumps({
-                        'Data': base64.b64encode(zip_bytes).decode('utf-8'),
-                        # The UserID is required by Panther for this API call, but we have
-                        # no way of acquiring it and it isn't used for anything. This is a
-                        # valid UUID used by the Panther deployment tool to indicate this
-                        # action was performed automatically.
-                        'UserID': '00000000-0000-4000-8000-000000000000',
-                    }),
-            }
-            response = client.invoke(FunctionName='panther-analysis-api',
-                                     InvocationType='RequestResponse',
-                                     LogType='None',
-                                     Payload=json.dumps(deprecated_payload))
-            response_str = response['Payload'].read().decode('utf-8')
-            response_payload = json.loads(response_str)
-
-            if response_payload.get('errorMessage') or response_payload.get(
-                    'statusCode') != 200:
-                logging.warning(
-                    'Failed to upload to Panther\n\tstatus code: %s\n\terror message: %s',
-                    response_payload.get('statusCode', 0),
-                    response_payload.get('errorMessage',
-                                         response_payload.get('body')))
-                return 1, ''
+        if response_payload.get('statusCode') != 200:
+            logging.warning(
+                'Failed to upload to Panther\n\tstatus code: %s\n\terror message: %s',
+                response_payload.get('statusCode', 0),
+                response_payload.get('errorMessage',
+                                     response_payload.get('body')))
+            return 1, ''
 
         body = json.loads(response_payload['body'])
         logging.info('Upload success.')
@@ -348,7 +322,7 @@ def setup_global_helpers(global_analysis: List[Any]) -> List[Any]:
         # If the module could not be loaded, continue to the next
         if load_err:
             invalid_specs.append((analysis_spec_filename, load_err))
-            break
+            continue
         sys.modules[analysis_id] = module
     return invalid_specs
 
@@ -459,6 +433,11 @@ def filter_analysis(analysis: List[Any], filters: Dict[str, List]) -> List[Any]:
                           os.path.join(file_name))
             filtered_analysis.append((file_name, dir_name, analysis_spec))
             continue
+        if fnmatch(dir_name, DATA_MODEL_LOCATION):
+            logging.debug('auto-adding data model file %s',
+                          os.path.join(file_name))
+            filtered_analysis.append((file_name, dir_name, analysis_spec))
+            continue
         match = True
         for key, values in filters.items():
             spec_value = analysis_spec.get(key, "")
@@ -636,7 +615,7 @@ def setup_parser() -> argparse.ArgumentParser:
         prog='panther_analysis_tool')
     parser.add_argument('--version',
                         action='version',
-                        version='panther_analysis_tool 0.4.2')
+                        version='panther_analysis_tool 0.4.5')
     subparsers = parser.add_subparsers()
 
     test_parser = subparsers.add_parser(
